# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

cvmat_rect <- function(ptr, x = 0L, y = 0L, width = 0L, height = 0L) {
    .Call('_opencv_cvmat_rect', PACKAGE = 'opencv', ptr, x, y, width, height)
}

cvmat_bbox <- function(ptr) {
    .Call('_opencv_cvmat_bbox', PACKAGE = 'opencv', ptr)
}

cvpoints_bbox <- function(ptr, pts) {
    .Call('_opencv_cvpoints_bbox', PACKAGE = 'opencv', ptr, pts)
}

cvpoints_chull <- function(pts) {
    .Call('_opencv_cvpoints_chull', PACKAGE = 'opencv', pts)
}

cvmat_polygon <- function(ptr, pts, convex = FALSE, crop = FALSE, color = 255L) {
    .Call('_opencv_cvmat_polygon', PACKAGE = 'opencv', ptr, pts, convex, crop, color)
}

cvmat_destroy <- function(image) {
    invisible(.Call('_opencv_cvmat_destroy', PACKAGE = 'opencv', image))
}

cvmat_dead <- function(image) {
    .Call('_opencv_cvmat_dead', PACKAGE = 'opencv', image)
}

cvmat_size <- function(image) {
    .Call('_opencv_cvmat_size', PACKAGE = 'opencv', image)
}

cvmat_new <- function() {
    .Call('_opencv_cvmat_new', PACKAGE = 'opencv')
}

cvmat_dupe <- function(image) {
    .Call('_opencv_cvmat_dupe', PACKAGE = 'opencv', image)
}

cvmat_read <- function(path) {
    .Call('_opencv_cvmat_read', PACKAGE = 'opencv', path)
}

cvmat_camera <- function() {
    .Call('_opencv_cvmat_camera', PACKAGE = 'opencv')
}

cvmat_write <- function(image, path) {
    .Call('_opencv_cvmat_write', PACKAGE = 'opencv', image, path)
}

cvmat_resize <- function(ptr, width = 0L, height = 0L) {
    .Call('_opencv_cvmat_resize', PACKAGE = 'opencv', ptr, width, height)
}

cvmat_raw_bgr <- function(image, width = 0L, height = 0L) {
    .Call('_opencv_cvmat_raw_bgr', PACKAGE = 'opencv', image, width, height)
}

cvmat_raw_bw <- function(image, width = 0L, height = 0L) {
    .Call('_opencv_cvmat_raw_bw', PACKAGE = 'opencv', image, width, height)
}

cvmat_bitmap <- function(ptr) {
    .Call('_opencv_cvmat_bitmap', PACKAGE = 'opencv', ptr)
}

cvmat_copyto <- function(from, to, mask) {
    .Call('_opencv_cvmat_copyto', PACKAGE = 'opencv', from, to, mask)
}

cvmat_info <- function(image) {
    .Call('_opencv_cvmat_info', PACKAGE = 'opencv', image)
}

cvmat_display <- function(ptr) {
    invisible(.Call('_opencv_cvmat_display', PACKAGE = 'opencv', ptr))
}

livestream <- function(filter, stop_on_result = FALSE) {
    .Call('_opencv_livestream', PACKAGE = 'opencv', filter, stop_on_result)
}

data_prefix <- function() {
    .Call('_opencv_data_prefix', PACKAGE = 'opencv')
}

set_num_threads <- function(n = 0L) {
    .Call('_opencv_set_num_threads', PACKAGE = 'opencv', n)
}

cvmat_grayscale <- function(src) {
    .Call('_opencv_cvmat_grayscale', PACKAGE = 'opencv', src)
}

cvmat_blur <- function(ptr, ksize) {
    .Call('_opencv_cvmat_blur', PACKAGE = 'opencv', ptr, ksize)
}

cvmat_sketch <- function(ptr, color) {
    .Call('_opencv_cvmat_sketch', PACKAGE = 'opencv', ptr, color)
}

cvmat_stylize <- function(ptr) {
    .Call('_opencv_cvmat_stylize', PACKAGE = 'opencv', ptr)
}

enums_types <- function(maximum = 4L) {
    .Call('_opencv_enums_types', PACKAGE = 'opencv', maximum)
}

enums_depth <- function() {
    .Call('_opencv_enums_depth', PACKAGE = 'opencv')
}

cvmat_face <- function(ptr, facedata, eyedata) {
    .Call('_opencv_cvmat_face', PACKAGE = 'opencv', ptr, facedata, eyedata)
}

cvmat_facemask <- function(ptr, facedata) {
    .Call('_opencv_cvmat_facemask', PACKAGE = 'opencv', ptr, facedata)
}

cvmat_mog2 <- function(ptr) {
    .Call('_opencv_cvmat_mog2', PACKAGE = 'opencv', ptr)
}

cvmat_knn <- function(ptr) {
    .Call('_opencv_cvmat_knn', PACKAGE = 'opencv', ptr)
}

cvmat_edges <- function(ptr) {
    .Call('_opencv_cvmat_edges', PACKAGE = 'opencv', ptr)
}

cvkeypoints_fast <- function(ptr, threshold = 0L, nonmaxSuppression = TRUE, type = 2L) {
    .Call('_opencv_cvkeypoints_fast', PACKAGE = 'opencv', ptr, threshold, nonmaxSuppression, type)
}

cvkeypoints_harris <- function(ptr, numOctaves = 6L, corn_thresh = 0.01, DOG_thresh = 0.01, maxCorners = 5000L, num_layers = 4L) {
    .Call('_opencv_cvkeypoints_harris', PACKAGE = 'opencv', ptr, numOctaves, corn_thresh, DOG_thresh, maxCorners, num_layers)
}

cvmat_hog <- function(ptr) {
    .Call('_opencv_cvmat_hog', PACKAGE = 'opencv', ptr)
}

cvmat_markers <- function(ptr) {
    .Call('_opencv_cvmat_markers', PACKAGE = 'opencv', ptr)
}

cvmat_qr_detect <- function(ptr, return_image = FALSE, use_wechat = TRUE) {
    .Call('_opencv_cvmat_qr_detect', PACKAGE = 'opencv', ptr, return_image, use_wechat)
}

cvversion <- function() {
    .Call('_opencv_cvversion', PACKAGE = 'opencv')
}

